import { useMemo } from 'react';
import { useObservableState } from '@equinor/fusion-observable/react';
import { useFramework } from '../useFramework';
export const useCurrentApp = () => {
    const provider = useFramework().modules.app;
    if (!provider) {
        throw Error('Current framework does not have AppModule configured');
    }
    const currentApp$ = useMemo(() => provider.current$, [provider]);
    const { value, error } = useObservableState(currentApp$, { initial: provider.current });
    return {
        currentApp: value,
        setCurrentApp: useMemo(() => provider.setCurrentApp.bind(provider), [provider]),
        clearCurrentApp: useMemo(() => provider.clearCurrentApp.bind(provider), [provider]),
        error,
    };
};
export default useCurrentApp;
//# sourceMappingURL=useCurrentApp.js.map